@@ -1,29 +1,29 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
-
+from collections.abc import Hashable
 import logging
 import time
 
-import numba
+# import numba
 import numpy as np
 import pandas as pd
 
+
 logger = logging.getLogger(__name__)
 
 
-def add_transition_info(ds, colname, threshold: float = None, extra_rows: int = 0):
-    """
-    calculate splits and add "secs" and "process_num" column to dataframe
-    """
+def add_transition_info(
+    ds: pd.DataFrame,
+    colname: Hashable,
+    threshold: float,
+    extra_rows: int = 0,
+    transition_col: str = "process_num",
+    time_col: str = "secs",
+) -> pd.DataFrame:
+    """Calculate splits and add "secs" and "process_num" column to dataframe."""
     logger.info("Start splitting process")
     now = time.time()
     # setze ersten Wert auf 0. (evtl auch noch den letzten?)
     # Bisschen unschön, aber nötig, damit start und end indexes in sync sind.
     col = ds[colname]
-    threshold if threshold else col.max() / 2
-
     start_indexes = get_transition_indices(col.to_numpy(), threshold)
     start_indexes = np.maximum(start_indexes - extra_rows, 0)
     end_indexes = get_transition_indices(col.to_numpy(), threshold, True)
@@ -37,30 +37,28 @@ def add_transition_info(ds, colname, threshold: float = None, extra_rows: int =
         end_indexes = [len(ds.index)]  # perhaps -1 ?
 
     logger.info("Found indices. Applying new columns to dataset....")
-    ds = ds.drop("secs", errors="ignore", axis=1)
+    ds = ds.drop(time_col, errors="ignore", axis=1)
     proc = np.full((len(ds.index),), np.nan)
     for i, (start, end) in enumerate(zip(start_indexes, end_indexes), start=1):
         proc[start:end] = i
     categories = [i + 1 for i in range(len(start_indexes))]
-    ds["process_num"] = pd.Categorical(proc, categories=categories)
-    ds["secs"] = ds.groupby("process_num").apply(calc_secs)["secs"]
+    ds[transition_col] = pd.Categorical(proc, categories=categories)
+    ds[time_col] = ds.groupby(transition_col).apply(calc_secs)[time_col]
     logger.info(f"Splitting took {(time.time() - now):.2f} seconds")
     return ds
 
 
-def calc_secs(ds):
+def calc_secs(ds: pd.DataFrame) -> pd.DataFrame:
     idx = ds.index.astype(int).to_numpy() / 1_000_000_000
     ds["secs"] = idx - idx[0] if len(ds.index) > 0 else np.nan
     return ds
 
 
-@numba.jit(nopython=True, parallel=True)
-def get_transition_indices(y: np.ndarray,
-                           threshold: float,
-                           falling_edge: bool = False) -> np.ndarray:
-    """
-    return indices where a transition occurs (default: detect rising edges)
-    """
+# @numba.jit(nopython=True, parallel=True)
+def get_transition_indices(
+    y: np.ndarray, threshold: float, falling_edge: bool = False
+) -> np.ndarray:
+    """Return indices where a transition occurs (default: detect rising edges)."""
     # Find where y crosses a threshold in a specific direction.
     lower = y < threshold
     higher = y >= threshold
@@ -70,12 +68,12 @@ def get_transition_indices(y: np.ndarray,
         return np.where(lower[:-1] & higher[1:])[0]
 
 
-@numba.jit(nopython=True, parallel=True)
-def find_transition_times(t: np.ndarray,
-                          y: np.ndarray,
-                          threshold: float,
-                          falling_edge: bool = False) -> np.ndarray:
-    """
+# @numba.jit(nopython=True, parallel=True)
+def find_transition_times(
+    t: np.ndarray, y: np.ndarray, threshold: float, falling_edge: bool = False
+) -> np.ndarray:
+    """Find transition times.
+
     Given the input signal `y` with samples at times `t`,
     find the times where `y` increases through the value `threshold`.
 
@@ -84,7 +82,6 @@ def find_transition_times(t: np.ndarray,
     Linear interpolation is used to estimate the time `t` between
     samples at which the transitions occur.
     """
-
     transition_indices = get_transition_indices(y, threshold, falling_edge)
 
     t0 = t[transition_indices]
@@ -97,9 +94,10 @@ def find_transition_times(t: np.ndarray,
     return transition_times
 
 
-@numba.jit(nopython=True)
-def periods(t: np.ndarray, y: np.ndarray, threshold):
-    """
+# @numba.jit(nopython=True)
+def periods(t: np.ndarray, y: np.ndarray, threshold: float):
+    """Return periods where y crosses the threshold over given time.
+
     Given the input signal `y` with samples at times `t`,
     find the time periods between the times at which the
     signal `y` increases through the value `threshold`.
@@ -112,6 +110,6 @@ def periods(t: np.ndarray, y: np.ndarray, threshold):
     return deltas
 
 
-def sliced(df, column_name, threshold):
+def sliced(df: pd.DataFrame, column_name: str, threshold: float):
     t_indices = get_transition_indices(df[column_name], threshold)
     return np.split(df, t_indices)
